package exemplo.controller;

import java.util.List;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.http.HttpStatus;
import org.springframework.http.ResponseEntity;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;

import exemplo.model.Veiculo;
import exemplo.repository.VeiculoRepository;

@Controller
@RequestMapping(path = "/veiculo/")
public class VeiculoController {

	@Autowired
	private VeiculoRepository veiculoRepo;
	
	@RequestMapping(value = "", method = RequestMethod.POST)
	public ResponseEntity<Veiculo> postCadastrar(@RequestBody Veiculo veiculo) {
		veiculo = this.veiculoRepo.save(veiculo);
		return new ResponseEntity<Veiculo>(veiculo, HttpStatus.CREATED);
	}
	
	@RequestMapping(value = "", method = RequestMethod.PUT)
	public ResponseEntity<?> putAtualizar(@RequestBody Veiculo veiculo) {
		if(this.veiculoRepo.findOne(veiculo.getId())==null) {
			   return new ResponseEntity(new CustomErrorType("Nao foi possivel atualizar. Veiculo com cod " + veiculo.getId() + " nao encontrado."),
	                    HttpStatus.NOT_FOUND);
		}	
		this.veiculoRepo.save(veiculo);
		return new ResponseEntity<>(HttpStatus.CREATED);		
	}
	
	@RequestMapping(value = "{id}", method = RequestMethod.DELETE)
	public ResponseEntity<?> deletePorId(@PathVariable long id) {
		if(this.veiculoRepo.findOne(id)==null) {
			   return new ResponseEntity(new CustomErrorType("Nao foi possivel deletar. Veiculo com id " + id + " nao encontrado."),
	                    HttpStatus.NOT_FOUND);
		}
		this.veiculoRepo.delete(id);
		return new ResponseEntity<>(HttpStatus.OK);	
	}
	
	@RequestMapping(value = "{id}", method = RequestMethod.GET)
	public ResponseEntity<?> buscarPorId(@PathVariable long id) {
		Veiculo veiculo = this.veiculoRepo.findOne(id);
		
		if(veiculo==null) {
			   return new ResponseEntity(new CustomErrorType("Nao foi possivel buscar o Veiculo com id " + id + "."),
	                    HttpStatus.NOT_FOUND);
		}
		return new ResponseEntity<Veiculo>(veiculo, HttpStatus.OK);
	}
	
	@RequestMapping(value = "", method = RequestMethod.GET)
	public ResponseEntity<List<Veiculo>> buscarTodos() {
		
		List<Veiculo> listaVeiculos = this.veiculoRepo.findAll();		
		
		return new ResponseEntity<List<Veiculo>>(listaVeiculos, HttpStatus.OK);
		
	}
}
